summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJoel Sherrill <joel.sherrill@OARcorp.com>2008-08-31 16:02:11 +0000
committerJoel Sherrill <joel.sherrill@OARcorp.com>2008-08-31 16:02:11 +0000
commite6778bc86006bbc7cad66eeff1e526898cd30380 (patch)
tree517b0df94437fc8ae331ea381c41af2bebcfdd67
parent2008-08-31 Joel Sherrill <joel.sherrill@oarcorp.com> (diff)
downloadrtems-e6778bc86006bbc7cad66eeff1e526898cd30380.tar.bz2
2008-08-31 Joel Sherrill <joel.sherrill@oarcorp.com>
* timer/timer.c, timer/timerisr.c: Rename timer driver methods to follow RTEMS programming conventions.
-rw-r--r--c/src/lib/libbsp/no_cpu/no_bsp/ChangeLog5
-rw-r--r--c/src/lib/libbsp/no_cpu/no_bsp/timer/timer.c20
-rw-r--r--c/src/lib/libbsp/no_cpu/no_bsp/timer/timerisr.c2
3 files changed, 16 insertions, 11 deletions
diff --git a/c/src/lib/libbsp/no_cpu/no_bsp/ChangeLog b/c/src/lib/libbsp/no_cpu/no_bsp/ChangeLog
index c90848bc52..4b9ec06801 100644
--- a/c/src/lib/libbsp/no_cpu/no_bsp/ChangeLog
+++ b/c/src/lib/libbsp/no_cpu/no_bsp/ChangeLog
@@ -1,3 +1,8 @@
+2008-08-31 Joel Sherrill <joel.sherrill@oarcorp.com>
+
+ * timer/timer.c, timer/timerisr.c: Rename timer driver methods to
+ follow RTEMS programming conventions.
+
2008-05-15 Joel Sherrill <joel.sherrill@OARcorp.com>
* startup/bspstart.c: Add capability for bootcard.c BSP Initialization
diff --git a/c/src/lib/libbsp/no_cpu/no_bsp/timer/timerisr.c b/c/src/lib/libbsp/no_cpu/no_bsp/timer/timerisr.c
index 7cbd49a050..ac8e54b06f 100644
--- a/c/src/lib/libbsp/no_cpu/no_bsp/timer/timerisr.c
+++ b/c/src/lib/libbsp/no_cpu/no_bsp/timer/timerisr.c
@@ -2,7 +2,7 @@
*
* If required this ISR is used to bump a count of interval "overflow"
* interrupts which have occurred since the timer was started. The
- * number of overflows is taken into account in the Read_timer()
+ * number of overflows is taken into account in the benchmark_timerread()
* routine if necessary.
*
* To reduce overhead this is best to be the "rawest" hardware interupt
diff --git a/c/src/lib/libbsp/no_cpu/no_bsp/timer/timer.c b/c/src/lib/libbsp/no_cpu/no_bsp/timer/timer.c
index 82ce3904dd..607d1c304b 100644
--- a/c/src/lib/libbsp/no_cpu/no_bsp/timer/timer.c
+++ b/c/src/lib/libbsp/no_cpu/no_bsp/timer/timer.c
@@ -2,8 +2,8 @@
*
* This file manages the benchmark timer used by the RTEMS Timing Test
* Suite. Each measured time period is demarcated by calls to
* Timer_initialize() and Read_timer(). Read_timer() usually returns
* the number of microseconds since Timer_initialize() exitted.
*
* NOTE: It is important that the timer start/stop overhead be
* determined when porting or modifying this code.
@@ -22,9 +22,9 @@
#include <bsp.h>
uint32_t Timer_interrupts;
-rtems_boolean Timer_driver_Find_average_overhead;
+rtems_boolean benchmark_timerfind_average_overhead;
-void Timer_initialize( void )
+void benchmark_timerinitialize( void )
{
/*
@@ -40,7 +40,7 @@ void Timer_initialize( void )
}
/*
* The following controls the behavior of Read_timer().
*
* AVG_OVEREHAD is the overhead for starting and stopping the timer. It
* is usually deducted from the number returned.
@@ -54,7 +54,7 @@ void Timer_initialize( void )
/* This value is in microseconds. */
#define LEAST_VALID 1 /* Don't trust a clicks value lower than this */
-int Read_timer( void )
+int benchmark_timerread( void )
{
uint32_t clicks;
uint32_t total;
@@ -73,7 +73,7 @@ int Read_timer( void )
total = clicks * 0;
- if ( Timer_driver_Find_average_overhead == 1 )
+ if ( benchmark_timerfind_average_overhead == 1 )
return total; /* in XXX microsecond units */
else {
if ( total < LEAST_VALID )
@@ -90,14 +90,14 @@ int Read_timer( void )
* in Timing Test Suite.
*/
-rtems_status_code Empty_function( void )
+rtems_status_code benchmark_timerempty_function( void )
{
return RTEMS_SUCCESSFUL;
}
-void Set_find_average_overhead(
+void benchmark_timerdisable_subtracting_average_overhead(
rtems_boolean find_flag
)
{
- Timer_driver_Find_average_overhead = find_flag;
+ benchmark_timerfind_average_overhead = find_flag;
}
@@ -2,8 +2,8 @@
* This file manages the benchmark timer used by the RTEMS Timing Test
* Suite. Each measured time period is demarcated by calls to
- * Timer_initialize() and Read_timer(). Read_timer() usually returns
- * the number of microseconds since Timer_initialize() exitted.
+ * benchmark_timerinitialize() and benchmark_timerread(). benchmark_timerread() usually returns
+ * the number of microseconds since benchmark_timerinitialize() exitted.
*
* NOTE: It is important that the timer start/stop overhead be
@@ -40,7 +40,7 @@ void Timer_initialize( void )
}
/*
- * The following controls the behavior of Read_timer().
+ * The following controls the behavior of benchmark_timerread().
*
* AVG_OVEREHAD is the overhead for starting and stopping the timer. It